<template>
  <el-main>
    <!--案件调查终结审批表-->
    <el-form ref="dataForm" :model="dataForm" label-width="110px" :disabled="dataForm.registerState == '1'">
      <el-form-item label="申请事项">
        <el-input v-model="dataForm.applyItem"></el-input>
      </el-form-item>
      <el-row>
        <el-col :span="12">
          <el-form-item label="案由" >
            <el-input v-model="dataForm.casePoint"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="立案日期">
            <el-date-picker
                v-model="dataForm.caseDate"
                :value-format="`yyyy-MM-dd`"
                type="date"
                placeholder="选择日期"
                style="width: 100%">
            </el-date-picker>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="当事人姓名">
            <el-input v-model="dataForm.litigant"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="法定代表人">
            <el-input v-model="dataForm.legalPerson"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="证件名称">
            <el-select v-model="dataForm.litigantCert" placeholder="请选择证件类型"
                       :disabled="dataForm.registerState == '1'" style="width: 100%;">
              <el-option
                  v-for="item in cardList"
                  :label="item.label"
                  :value="item.value">
              </el-option>
            </el-select>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="证件号码">
            <el-input v-model="dataForm.certNo"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="住址">
            <el-input v-model="dataForm.address"></el-input>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="电话">
            <el-input v-model="dataForm.phone"></el-input>
          </el-form-item>
        </el-col>
      </el-row>
      <el-form-item label="违法事实和证据">
        <el-input type="textarea" v-model="dataForm.illegalFact"></el-input>
      </el-form-item>
      <el-form-item label="处罚理由和依据">
        <el-input type="textarea" v-model="dataForm.punishBasis"></el-input>
      </el-form-item>
      <public-opinion ref="publicOpinion" :registerState="dataForm.registerState"></public-opinion>
      <WordView ref="wordInfo" :isShowYulan="showView" @cancel="cancelWord"></WordView>
    </el-form>
    <div style="text-align: center;">
      <el-button v-if="dataForm.registerState != '1'" plain @click="dataFormSubmit('0')">保存</el-button>
      <el-button v-if="dataForm.registerState != '1'" type="warning" plain @click="dataFormSubmit('1')">定稿</el-button>
      <el-button type="primary" plain @click="viewVord(dataForm)">预览</el-button>
      <el-button type="success" plain @click="downloadWord(dataForm)">下载</el-button>
    </div>
  </el-main>
</template>

<script>
import {getObj,saveObj} from '@/api/News/examinationInvestigationTermination'
import publicOpinion from "@/views/News/publicOpinion"
import WordView from '@/views/News/word-view/index'
import moment from "moment";
import {remote} from "@/api/admin/dict"


export default {
  name: "examination_investigation_termination",
  props: ['isShowYulan', 'id', 'processId'],
  components: {
    // Dict,
    publicOpinion,
    WordView
  },
  data() {
    return {
      showView: false,
      cardList: [],
      dataForm: {
        applyItem: '',
        casePoint: '',
        caseDate: '',
        litigant: '',
        legalPerson: '',
        litigantCert: '',
        certNo: '',
        address: '',
        phone: '',
        illegalFact: '',
        punishBasis: '',
      },
      imgSize : {     //控制导出的word图片大小
          autographOne: [120, 35],
          autographTwo: [120, 35],
          autographDept: [120, 35],
          autographLegal: [120, 35],
          autographOrgan: [120, 35]
      },
    }
  },
  created() {
    this.init()
  },
  methods: {
    init() {
      //查询字典
      remote('document_type').then(res => {
        this.cardList = res.data.data;
      })

      getObj(this.id).then((res) => {
        // if (res.success) {
          // 转换null为""
          /*let v = res.result;
          for (let attr in v) {
            if (v[attr] == null) {
              v[attr] = "";
            }
          }
          let str = JSON.stringify(v);
          let data = JSON.parse(str);*/
          this.dataForm = res.data.data;
          //查询公共意见
          this.$nextTick(() => {
            this.$refs.publicOpinion.init(this.dataForm.publicOpinion);
          })
        // }
      });
    },
    dataFormSubmit(type) {
      this.$refs['dataForm'].validate((valid) => {
        if (valid) {
          let obj = this;
          if ("1" == type) {
            this.$confirm('保存为定稿将不能修改，是否继续？', '提示', {
              confirmButtonText: '是',
              cancelButtonText: '否',
              type: 'warning'
            }).then(function () {
              obj.submitLoading = true;
              obj.dataForm.registerState = type;
              obj.dataForm.registerId = obj.id;
              obj.dataForm.processId = obj.processId;
              saveObj(obj.dataForm).then((res) => {
                if (res.data.code == 0) {
                  obj.$message.success("操作成功");
                  obj.cancel();
                  obj.$emit('getDataList');
                }
              })
            })
          } else {
            this.submitLoading = true;
            this.dataForm.registerState = type;
            this.dataForm.registerId = obj.id;
            this.dataForm.processId = this.processId;
            saveObj(this.dataForm).then((res) => {
              if (res.data.code == 0) {
                this.$message.success("操作成功");
                this.cancel();
                this.$emit('getDataList');
              }
            })
          }
        }
      })
    },
    cancel() {
      this.$emit('cancel', false)
    },
    cancelWord() {
      this.showView = false;
    },
    viewVord(data) {
      if(data.registerState == null || data.registerState == ""){
        //预览前先进行保存
        data.registerState = '0';
        data.registerId = this.id;
        data.processId = this.processId;
        saveObj(data).then((res) => {
        })
      }
      //↓↓↓↓↓↓以下部分根据具体业务修改↓↓↓↓↓↓
      //格式转换
      let wordData = this.transforData(data);
      let arry = ['autographOne', 'autographTwo', 'autographDept', 'autographLegal', 'autographOrgan']
      //↑↑↑↑↑↑以上部分根据具体业务修改↑↑↑↑↑↑
      this.showView = true;
      this.$nextTick(() => {
        this.$refs.wordInfo.initMore(wordData, "/wordes/ajdczj.docx",arry, this.imgSize);
      })
    },
    downloadWord(data) {
      if(data.registerState == null || data.registerState == ""){
        //预览前先进行保存
        data.registerState = '0';
        data.registerId = this.id;
        data.processId = this.processId;
        saveObj(data).then((res) => {
        })
      }
      let wordData = this.transforData(data);
      let arry = ['autographOne', 'autographTwo', 'autographDept', 'autographLegal', 'autographOrgan']
      this.$nextTick(() => {
          this.$refs.wordInfo.exportDocMore(wordData, "/wordes/ajdczj.docx", "案件调查终结审批表.docx",arry, this.imgSize);
      })
    },
    transforData(obj) {
      let s = JSON.stringify(obj);
      let data = JSON.parse(s);
      if (data.caseDate != '' && data.caseDate != null) {
        data.caseDate = moment(data.caseDate).format('YYYY年MM月DD日');
      }
      let opinion = data.publicOpinion;
      for (let attr in opinion) {
        if (opinion[attr] == null) {
          data[attr] = '';
        } else {
          data[attr] = opinion[attr];
        }
      }
      let str = JSON.stringify(data);
      let jsonData = JSON.parse(str);
      data = jsonData;

      if (opinion.undertakeDate != '' && opinion.undertakeDate != null) {
        data.undertakeDate = moment(opinion.undertakeDate).format('YYYY年MM月DD日');
      } else {
        data.undertakeDate = '  年  月  日'
      }
      if (opinion.takeDate != '' && opinion.takeDate != null) {
        data.takeDate = moment(opinion.takeDate).format('YYYY年MM月DD日');
      } else {
        data.takeDate = '  年  月  日'
      }
      if (opinion.legalDate != '' && opinion.legalDate != null) {
        data.legalDate = moment(opinion.legalDate).format('YYYY年MM月DD日');
      } else {
        data.legalDate = '  年  月  日'
      }
      if (opinion.organDate != '' && opinion.organDate != null) {
        data.organDate = moment(opinion.organDate).format('YYYY年MM月DD日');
      } else {
        data.organDate = '  年  月  日'
      }
      return data;
    }
  }
}
</script>

<style scoped>

</style>
